pub struct EntryPoint {
pub kind: EntryPointKind,
pub fptr: fn(),
pub module_path: &'static str,
pub file: &'static str,
pub line: u32,
}Expand description
Export is a structure that contains information about the exported function.
This is used to register the export and its name and physical location in the smart contract source code.
Fields
kind: EntryPointKindThe kind of entry point that is being registered.
fptr: fn()module_path: &'static strfile: &'static strline: u32Trait Implementations