Vector

Struct Vector 

pub struct Vector<T> { /* private fields */ }

Implementations

Source

impl<T> Vector<T>

pub fn new<S: Into<String>>(prefix: S) -> Self

Constructs a new, empty Vector<T>.

The vector header will not write itself to the GS, even if values are pushed onto it later.

pub fn push(&mut self, value: T)

Appends an element to the back of a collection.

pub fn pop(&mut self) -> Option<T>

Removes the last element from a vector and returns it, or None if it is empty.

pub fn contains(&self, value: &T) -> bool
where T: PartialEq,

Returns true if the slice contains an element with the given value.

This operation is O(n).

pub fn get(&self, index: u64) -> Option<T>

Returns an element at index, deserialized.

pub fn iter(&self) -> impl Iterator<Item = T> + '_

Returns an iterator over self, with elements deserialized.

pub fn insert(&mut self, index: u64, value: T)

Inserts an element at position index within the vector, shifting all elements after it to the right.

pub fn clear(&mut self)

Clears the vector, removing all values from the global state. This is potentially expensive, as it requires an iteration over all elements to remove them from the global state.

pub fn len(&self) -> u64

Returns the number of elements in the vector, also referred to as its ‘length’.

pub fn is_empty(&self) -> bool

Returns true if the vector contains no elements.

Binary searches this vector for a given element. If the vector is not sorted, the returned result is unspecified and meaningless.

pub fn binary_search_by<F>(&self, f: F) -> Result<u64, u64>
where F: FnMut(&T) -> Ordering,

Binary searches this slice with a comparator function.

The comparator function should return an Ordering that indicates whether its argument is Less, Equal or Greater the desired target. If the slice is not sorted or if the comparator function does not implement an order consistent with the sort order of the underlying slice, the returned result is unspecified and meaningless.

pub fn remove(&mut self, index: u64) -> Option<T>

Removes the element at the specified index and returns it.

Note: Because this shifts over the remaining elements, it has a worst-case performance of O(n). If you don’t need the order of elements to be preserved, use swap_remove instead.

pub fn swap_remove(&mut self, index: u64) -> Option<T>

Removes the element at the specified index and returns it.

The removed element is replaced by the last element of the vector. This does not preserve ordering of the remaining elements, but is O(1).

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&T) -> bool,

Retains only the elements specified by the predicate.