IterableMapHash

Trait IterableMapHash 

pub trait IterableMapHash:
    PartialEq
    + BorshSerialize
    + BorshDeserialize {
    // Provided method
    fn compute_hash(&self) -> u64 { ... }
}
Trait for types that can be used as keys in IterableMap. Must produce a deterministic hash.

A blanket implementation is provided for all types that implement BorshSerialize.

Provided Methods

fn compute_hash(&self) -> u64

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl IterableMapHash for i8

Source

impl IterableMapHash for i16

Source

impl IterableMapHash for i32

Source

impl IterableMapHash for i64

Source

impl IterableMapHash for i128

Source

impl IterableMapHash for u8

Source

impl IterableMapHash for u16

Source

impl IterableMapHash for u32

Source

impl IterableMapHash for u64

Source

impl IterableMapHash for u128

Implementors