pub enum OwnableError {
NotAuthorized,
}Expand description
Represents the possible errors that can occur during ownership operations.
Variants
NotAuthorized
The caller is not authorized to perform the action.