ContractHandle

Struct ContractHandle 

pub struct ContractHandle<T: ContractRef> { /* private fields */ }

Implementations

Source

impl<T: ContractRef> ContractHandle<T>

pub const fn from_address(contract_address: Address) -> Self

pub fn build_call(&self) -> CallBuilder<T>

pub fn call<'a, CallData: ToCallData>( &self, func: impl FnOnce(T) -> CallData, ) -> Result<CallData::Return<'a>, CallError>
where CallData::Return<'a>: BorshDeserialize,

A shorthand form to call contracts with default settings.

pub fn try_call<CallData: ToCallData>( &self, func: impl FnOnce(T) -> CallData, ) -> Result<CallResult<CallData>, CallError>

A shorthand form to call contracts with default settings.

pub fn contract_address(&self) -> Address

pub fn entity(&self) -> Entity

pub fn balance(&self) -> u64

Returns the balance of the contract.