pub enum EntryPointKind {
SmartContract {
struct_name: &'static str,
name: &'static str,
},
TraitImpl {
trait_name: &'static str,
impl_name: &'static str,
name: &'static str,
},
Function {
name: &'static str,
},
}Expand description
The kind of export that is being registered.
This is used to identify the type of export and its name.
Depending on the location of given function it may be registered as a:
SmartContract(if it’s part of aimpl Contractblock),TraitImpl(if it’s part of aimpl Trait for Contractblock),Function(if it’s a standalone function).
This is used to dispatch exports under native code i.e. you want to write a test that calls “foobar” regardless of location.
Variants
SmartContract
Smart contract.
This is used to identify the smart contract and its name.
The struct_name is the name of the smart contract that is being registered.
The name is the name of the function that is being registered.
TraitImpl
Trait implementation.
This is used to identify the trait implementation and its name.
The trait_name is the name of the trait that is being implemented.
The impl_name is the name of the implementation.
The name is the name of the function that is being implemented.
Function
Function export.
This is used to identify the function export and its name.
The name is the name of the function that is being exported.
Implementations