pub trait IterableMapHash:
PartialEq
+ BorshSerialize
+ BorshDeserialize {
// Provided method
fn compute_hash(&self) -> u64 { ... }
}Expand description
Trait for types that can be used as keys in IterableMap. Must produce a deterministic hash.
A blanket implementation is provided for all types that implement BorshSerialize.
Provided Methods
fn compute_hash(&self) -> u64
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.